.. _python:

Python API
==========

.. automodule:: tblite

.. note::

   The documentation of the ASE integration can be found in :ref:`ase-calc`.


Library interface
-----------------

.. automodule:: tblite.interface


Structure
~~~~~~~~~

.. autoclass:: Structure
   :members:


Calculator
~~~~~~~~~~

.. autoclass:: Calculator
   :members:


Result
~~~~~~

.. autoclass:: Result
   :members:
